@@ -1,7 +1,4 @@
 #imports
-import curses
-import cursor
-
 import string
 import datetime
 import os
